==> manydhcp2.5.2.tar.bz2: manydhcp/house/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['house-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['house_id'])) {puterror($result2['skin'],$TEXT['error-house5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['house_id'])>5) {puterror($result2['skin'],$TEXT['error-house6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['house_id'] = rep($_GET['house_id']);

  //*************************************
  //Информация для лога
  $query10 = "SELECT `house` FROM `tbl_house` WHERE `house_id`='".$_GET['house_id']."' ";
  $result10 = mysql_query($query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl10']); require_once "../utils/bottom_adm.php"; exit();}
      $result_dom = mysql_fetch_array($result10);

  //Вводим переменные
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-house2'];
  $what = $result_dom['house'].$TEXT['log-id'].$_GET['house_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_house` WHERE `house_id`='".$_GET['house_id']."' LIMIT 1";
  if(mysql_query($query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysql_query($query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-house7']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/house/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['house-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['house_id'])) {puterror($result2['skin'],$TEXT['error-house5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['house_id'])>5) {puterror($result2['skin'],$TEXT['error-house6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['house_id'] = rep($_GET['house_id']);

  //*************************************
  //Информация для лога
  $query10 = "SELECT `house` FROM `tbl_house` WHERE `house_id`='".$_GET['house_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl10']); require_once "../utils/bottom_adm.php"; exit();}
      $result_dom = mysqli_fetch_array($result10,MYSQLI_ASSOC);

  //Вводим переменные
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-house2'];
  $what = $result_dom['house'].$TEXT['log-id'].$_GET['house_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_house` WHERE `house_id`='".$_GET['house_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-house7']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>
